@@ -12,20 +12,19 @@ def _run_cmd_seq(*args_list):
         results = (_verbose_invoke(runner, args) for args in args_list)
         assert all(res.exit_code == 0 for res in results)
 
+
 def test_all_templates():
     from texproject.filesystem import template_linker
     for tname in template_linker.list_names():
         _run_cmd_seq(
             ['init', tname],
-            ['validate']
-            )
+            ['validate'])
 
 def test_archive():
     _run_cmd_seq(
             ['init', 'preprint'],
             ['import', '--macro', 'tikz'],
-            ['archive', '--include', 'arxiv', 'out.tar']
-            )
+            ['archive', '--mode', 'arxiv', 'out.tar'])
 
 def test_git():
     _run_cmd_seq(
@@ -35,5 +34,4 @@ def test_git():
                 '--repo-description', 'some description',
                 '--no-wiki',
                 '--issues',
-                '--repo-visibility', 'private']
-            )
+                '--repo-visibility', 'private'])
